@@ -16,8 +16,14 @@ if __name__ == '__main__':
     test_table = SimpleTable("foo", ["[bar]", "baz"])
     test_table2 = SimpleTable("bar", ["testing", "this"])
 
+    color_table = SimpleTable("color", ["red", "blue", "green", "yellow", "orange", "purple"])
+
     test = PyChance()
     test.add_table("foo", test_table)
     test.add_table("bar", test_table2)
+    test.add_table("color", color_table)
     print(test.parser.parse("This is a [foo] test [bar]."))
 
+    print(test.parser.parse("Color 1: [color] Color 2: [color] Color 3: [color]"))
+
+    print(test.parser.parse("{a} test {a}  extra test"))
\ No newline at end of file
